<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

if ( ! function_exists( 'musicsong_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Musicsong Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function musicsong_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'musicsong_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'musicsong_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Musicsong Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function musicsong_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'musicsong_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'musicsong_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Musicsong Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function musicsong_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'musicsong_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[slider_content_type]' )->value();
	return musicsong_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[slider_content_type]' )->value();
	return musicsong_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[slider_content_type]' )->value();
	return musicsong_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[slider_content_type]' )->value();
	return musicsong_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if slider section content type is product category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[slider_content_type]' )->value();
	return musicsong_pro_is_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if playlist section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_playlist_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[playlist_section_enable]' )->value() );
}


/**
 * Check if about section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[about_content_type]' )->value();
	return musicsong_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[about_content_type]' )->value();
	return musicsong_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[about_content_type]' )->value();
	return musicsong_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if hero content section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_hero_content_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[hero_content_section_enable]' )->value() );
}

/**
 * Check if hero content section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_hero_content_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[hero_content_content_type]' )->value();
	return musicsong_pro_is_hero_content_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero content section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_hero_content_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[hero_content_content_type]' )->value();
	return musicsong_pro_is_hero_content_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero content section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_hero_content_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[hero_content_content_type]' )->value();
	return musicsong_pro_is_hero_content_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[service_content_type]' )->value();
	return musicsong_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[service_content_type]' )->value();
	return musicsong_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[service_content_type]' )->value();
	return musicsong_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[service_content_type]' )->value();
	return musicsong_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest release section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_section_enable]' )->value() );
}

/**
 * Check if latest release section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest release section seperator.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if latest release section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest release section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest release section content type is product.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_latest_release_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[latest_release_content_type]' )->value();
	return musicsong_pro_is_latest_release_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[cta_content_type]' )->value();
	return musicsong_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[cta_content_type]' )->value();
	return musicsong_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[cta_content_type]' )->value();
	return musicsong_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if event section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[event_content_type]' )->value();
	return musicsong_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[event_content_type]' )->value();
	return musicsong_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[event_content_type]' )->value();
	return musicsong_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[event_content_type]' )->value();
	return musicsong_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[event_content_type]' )->value();
	return musicsong_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_content_type]' )->value();
	return musicsong_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_content_type]' )->value();
	return musicsong_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_content_type]' )->value();
	return musicsong_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is product.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_content_type]' )->value();
	return musicsong_pro_is_gallery_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if gallery section content type is product category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_gallery_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[gallery_content_type]' )->value();
	return musicsong_pro_is_gallery_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[testimonial_content_type]' )->value();
	return musicsong_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if promotion section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if promotion section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[promotion_content_type]' )->value();
	return musicsong_pro_is_promotion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if promotion section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_promotion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[promotion_content_type]' )->value();
	return musicsong_pro_is_promotion_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if promotion section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_promotion_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[promotion_content_type]' )->value();
	return musicsong_pro_is_promotion_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if product section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[product_content_type]' )->value();
	return musicsong_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[product_content_type]' )->value();
	return musicsong_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if artists section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[artists_section_enable]' )->value() );
}

/**
 * Check if artists section seperator.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if artists section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if artists section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if artists section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if artists section content type is position.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if artists section content type is custom.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_artists_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[artists_content_type]' )->value();
	return musicsong_pro_is_artists_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[blog_content_type]' )->value();
	return musicsong_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[blog_content_type]' )->value();
	return musicsong_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[blog_content_type]' )->value();
	return musicsong_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[blog_content_type]' )->value();
	return musicsong_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[subscription_section_enable]' )->value() ) && class_exists( 'Jetpack' );
}


/**
 * Check if destination section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[destination_section_enable]' )->value() );
}

/**
 * Check if destination section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if destination section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if destination section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_dest_destinations_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if destination section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if destination section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if destination section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_destination_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[destination_content_type]' )->value();
	return musicsong_pro_is_destination_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if tour section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[tour_section_enable]' )->value() );
}

/**
 * Check if tour section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if tour section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if tour section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_dest_tours_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( 'tour' == $content_type );
}

/**
 * Check if tour section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if tour section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if tour section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_tour_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[tour_content_type]' )->value();
	return musicsong_pro_is_tour_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}


/**
 * Check if team section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[team_content_type]' )->value();
	return musicsong_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[team_content_type]' )->value();
	return musicsong_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[team_content_type]' )->value();
	return musicsong_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if product section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[collection_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

function musicsong_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[featured_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

function musicsong_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[featured_content_type]' )->value();
	return musicsong_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[featured_content_type]' )->value();
	return musicsong_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[featured_content_type]' )->value();
	return musicsong_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is recent.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_featured_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[featured_content_type]' )->value();
	return musicsong_pro_is_featured_section_enable( $control ) && ( 'recent' == $content_type );
}

function musicsong_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function musicsong_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_1]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function musicsong_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_2]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function musicsong_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_3]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function musicsong_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_1]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function musicsong_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_2]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function musicsong_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[trending_content_type_3]' )->value();
	return musicsong_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}



/**
 * Check if popular section is enabled.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is post.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[popular_content_type]' )->value();
	return musicsong_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[popular_content_type]' )->value();
	return musicsong_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[popular_content_type]' )->value();
	return musicsong_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is recent.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_popular_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[popular_content_type]' )->value();
	return musicsong_pro_is_popular_section_enable( $control ) && ( 'recent' == $content_type );
}

function musicsong_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[recent_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

function musicsong_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[recent_content_type]' )->value();
	return musicsong_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[recent_content_type]' )->value();
	return musicsong_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[recent_content_type]' )->value();
	return musicsong_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is recent.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_recent_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[recent_content_type]' )->value();
	return musicsong_pro_is_recent_section_enable( $control ) && ( 'recent' == $content_type );
}



function musicsong_pro_is_most_view_section_enable( $control ) {
	return ( $control->manager->get_setting( 'musicsong_pro_theme_options[most_view_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

function musicsong_pro_is_most_view_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[most_view_content_type]' )->value();
	return musicsong_pro_is_most_view_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_view section content type is page.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_most_view_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[most_view_content_type]' )->value();
	return musicsong_pro_is_most_view_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_view section content type is category.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_most_view_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[most_view_content_type]' )->value();
	return musicsong_pro_is_most_view_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_view section content type is most_view.
 *
 * @since Musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function musicsong_pro_is_most_view_section_content_most_view_enable( $control ) {
	$content_type = $control->manager->get_setting( 'musicsong_pro_theme_options[most_view_content_type]' )->value();
	return musicsong_pro_is_most_view_section_enable( $control ) && ( 'recent' == $content_type );
}
