<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 * @return array An array of default values
 */

function musicsong_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$musicsong_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fd2d55',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'dark-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'musicsong-pro' ), '[the-year]', '[site-link]' ) . esc_html__( ' All Rights Reserved | ', 'musicsong-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'musicsong-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Playlist,About Us,Hero Content,Services,Latest Release,Call to Action,Event,Gallery,Testimonial,Promotion,Product,Artists,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'musicsong-pro' ),
		'read_more_text' 				=> esc_html__( 'Read Full Article', 'musicsong-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_search_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_title'				=> esc_html__( 'Learn More', 'musicsong-pro' ),

		// Playlist
		'playlist_section_enable'		=> true,

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_column'					=> 'col-2',
		'about_title'					=> esc_html__( 'Popular', 'musicsong-pro' ),
		'about_subtitle'				=> esc_html__( 'Artist of the Week', 'musicsong-pro' ),
		'about_description'				=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'musicsong-pro' ),

		// hero content
		'hero_content_section_enable'	=> true,
		'hero_content_content_type'		=> 'page',
		'hero_content_title'			=> esc_html__( 'Weekly Mix', 'musicsong-pro' ),
		'hero_content_subtitle'			=> esc_html__( 'Best Things of the week', 'musicsong-pro' ),
		'hero_content_description'		=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'musicsong-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',

		// latest release
		'latest_release_section_enable'	=> true,
		'latest_release_content_type'	=> 'category',
		'latest_release_title'			=> esc_html__( 'Latest Release', 'musicsong-pro' ),
		'latest_release_subtitle'		=> esc_html__( 'Newest albums & singles.', 'musicsong-pro' ), 
		'latest_release_btn_title'		=> esc_html__( 'View All Release', 'musicsong-pro' ), 
		'latest_release_description'	=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'musicsong-pro' ), 

		// Call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'Music is My Escape', 'musicsong-pro' ),
		'cta_subtitle'					=> esc_html__( 'Music is a world within itself', 'musicsong-pro' ),
		'cta_description'				=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'musicsong-pro' ),

		// Event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 3,
		'event_title'					=> esc_html__( 'Upcoming Events', 'musicsong-pro' ),
		'event_subtitle'				=> esc_html__( 'Amazing shows around 2019', 'musicsong-pro' ),
		'event_readmore'				=> esc_html__( 'Buy Ticket', 'musicsong-pro' ),
		'event_btn_title'				=> esc_html__( 'View All Events', 'musicsong-pro' ),

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 5,
		'gallery_title'					=> esc_html__( 'Because every picture has a story to tell.', 'musicsong-pro' ),
		'gallery_subtitle'				=> esc_html__( 'Image Gallery', 'musicsong-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_title'				=> esc_html__( 'Loved by business and individuals across the globe.', 'musicsong-pro' ),
		'testimonial_subtitle'			=> esc_html__( 'Testimonials', 'musicsong-pro' ),

		// Promotion
		'promotion_section_enable'		=> true,
		'promotion_content_type'		=> 'page',
		'promotion_title'				=> esc_html__( 'Perfect Solution for Every Musicians and Listener out there', 'musicsong-pro' ),
		'promotion_subtitle'			=> esc_html__( 'Record With Us for quality music', 'musicsong-pro' ),
		'promotion_description'			=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'musicsong-pro' ),
		'promotion_btn_title'			=> esc_html__( 'Try Free Now', 'musicsong-pro' ),
		'promotion_alt_btn_title'		=> esc_html__( 'Get a Demo', 'musicsong-pro' ),

		// Product
		'product_section_enable'		=> false,
		'product_content_type'			=> 'product-category',
		'product_count'					=> 4,
		'product_title'					=> esc_html__( 'Shop Our Products', 'musicsong-pro' ),
		'product_subtitle'				=> esc_html__( 'Discover our latest products', 'musicsong-pro' ),

		'collection_section_enable'		=> false,
		'collection_title'				=> esc_html__( 'Spring Collections', 'musicsong-pro' ),
		'collection_subtitle'			=> esc_html__( 'Discover our latest products', 'musicsong-pro' ),

		'featured_section_enable'		=> false,

		// artists
		'artists_section_enable'		=> true,
		'artists_content_type'			=> 'category',
		'artists_count'					=> 4,
		'artists_column'				=> 'col-4',
		'artists_title'					=> esc_html__( 'Recommended Artist', 'musicsong-pro' ),
		'artists_subtitle'				=> esc_html__( 'Discover your Favourite one', 'musicsong-pro' ),
		'artists_btn_title'				=> esc_html__( 'View All Artists', 'musicsong-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 5,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Our Latest Blog', 'musicsong-pro' ),
		'blog_subtitle'					=> esc_html__( 'Check our blog, resources and more', 'musicsong-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Posts', 'musicsong-pro' ),

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'category',
		'popular_count'						=> 3,


		// featured
		'featured_section_enable'			=> true,
		'featured_content_type'				=> 'category',
		'featured_count'					=> 4,
		'featured_title'					=> esc_html__( 'Featured News', 'musicsong-pro' ),

		// recent
		'recent_section_enable'			=> true,
		'recent_content_type'				=> 'category',
		'recent_count'					=> 3,
		'recent_title'					=> esc_html__( 'Recent News', 'musicsong-pro' ),

		// most_view
		'most_view_section_enable'			=> true,
		'most_view_content_type'				=> 'category',
		'most_view_count'					=> 3,
		'most_view_title'					=> esc_html__( 'Most Viewed News', 'musicsong-pro' ),


		// Subscription
		'subscription_section_enable'	=> false,
		'subscription_title'			=> esc_html__( 'Don’t miss any updates, grab our monthly newsletter', 'musicsong-pro' ),
		'subscription_subtitle'			=> esc_html__( 'Subscribe now and stay tuned', 'musicsong-pro' ),

		// destination
		'destination_section_enable'			=> true,
		'destination_count'					=> 6,
		'destination_content_type'			=> 'category',
		'destination_title'					=> esc_html__( 'Great Tour Around World', 'travel-ultimate-pro' ),
		'destination_subtitle'				=> esc_html__( 'Find our most', 'travel-ultimate-pro' ),
		'destination_btn'					=> esc_html__( 'Book Now', 'travel-ultimate-pro' ),

		// tour
		'tour_section_enable'			=> true,
		'tour_count'					=> 6,
		'tour_content_type'			=> 'category',
		'tour_title'					=> esc_html__( 'Great Tour Around World', 'travel-ultimate-pro' ),
		'tour_subtitle'				=> esc_html__( 'Find our most', 'travel-ultimate-pro' ),
		'tour_btn'					=> esc_html__( 'Book Now', 'travel-ultimate-pro' ),

		//team 
		'team_section_enable'				=> true,
		'team_content_type'					=> 'page',
		'team_count'						=> 4,
		'team_column_layout'				=> 'col-4',
		'team_title'						=> esc_html__( 'Our Creative Team', 'corponess-pro' ),
		'team_sub_title'					=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start and terrified.', 'corponess-pro' ),	
		'team_btn_label'					=> esc_html__( 'View All Team', 'corponess-pro' ),

		//counter 
		'counter_section_enable'			=> true,
		'counter_count'						=> 4,


		//trending_product 
		'trending_product_section_enable'				=> true,
		'trending_product_content_type'					=> 'page',
		'trending_product_count'						=> 4,
		'trending_product_section_buttom_slider_enable'	=> true,
		'trending_product_title'						=> esc_html__( 'Our Skilled Teachers', 'musicsong-pro' ),
	);

	$output = apply_filters( 'musicsong_pro_default_theme_options', $musicsong_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}