<?php
/**
 * recent Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add recent section
$wp_customize->add_section( 'musicsong_pro_recent_section', array(
	'title'             => esc_html__( 'Recent','musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// recent content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_section_enable]', array(
	'default'			=> 	$options['recent_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[recent_section_enable]', array(
	'label'             => esc_html__( 'Recent Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_recent_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

	// recent title setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['recent_title'],
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[recent_title]', array(
		'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
		'section'        	=> 'musicsong_pro_recent_section',
		'active_callback' 	=> 'musicsong_pro_is_recent_section_enable',
		'type'				=> 'text',
	) );



	// recent content type control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_content_type]', array(
		'default'          	=> $options['recent_content_type'],
		'sanitize_callback' => 'musicsong_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[recent_content_type]', array(
		'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_recent_section',
		'type'				=> 'select',
		'active_callback' 	=> 'musicsong_pro_is_recent_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
			'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
			'category' 	=> esc_html__( 'Category', 'musicsong-pro' ),
			'recent' 	=> esc_html__( 'Recent', 'musicsong-pro' ),
		),
	) );

	// Event social icons number control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_count]', array(
		'default'          	=> $options['recent_count'],
		'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
		'validate_callback' => 'musicsong_pro_validate_recent_count',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[recent_count]', array(
		'label'             => esc_html__( 'Number of Posts', 'musicsong-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_recent_section',
		'active_callback'   => 'musicsong_pro_is_recent_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 4,
			'max'	=> 12,
			'style' => 'width: 100px;'
			),
	) );

	for ( $i = 1; $i <= $options['recent_count']; $i++ ) :
		// recent pages drop down chooser control and setting
		$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_content_page_' . $i . ']', array(
			'sanitize_callback' => 'musicsong_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[recent_content_page_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
			'section'           => 'musicsong_pro_recent_section',
			'choices'			=> musicsong_pro_page_choices(),
			'active_callback'	=> 'musicsong_pro_is_recent_section_content_page_enable',
		) ) );

		// recent posts drop down chooser control and setting
		$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_content_post_' . $i . ']', array(
			'sanitize_callback' => 'musicsong_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[recent_content_post_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
			'section'           => 'musicsong_pro_recent_section',
			'choices'			=> musicsong_pro_post_choices(),
			'active_callback'	=> 'musicsong_pro_is_recent_section_content_post_enable',
		) ) );
	endfor;

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'musicsong_pro_theme_options[recent_content_category]', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[recent_content_category]', array(
		'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_recent_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'musicsong_pro_is_recent_section_content_category_enable'
	) ) );

	// Add dropdown categories setting and control.
	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_category_exclude]', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_category_list',
	) ) ;

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Category_Control( $wp_customize,'musicsong_pro_theme_options[recent_category_exclude]', array(
		'label'             => esc_html__( 'Select Excluding Categories', 'musicsong-pro' ),
		'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_recent_section',
		'type'              => 'dropdown-categories',
		'active_callback'	=> 'musicsong_pro_is_recent_section_content_recent_enable'
	) ) );

	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_ads_image]', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'musicsong_pro_theme_options[recent_ads_image]',
			array(
			'label'       		=> esc_html__( 'Image', 'musicsong-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'musicsong-pro' ), 512, 520 ),
			'section'     		=> 'musicsong_pro_recent_section',
			'active_callback'	=> 'musicsong_pro_is_recent_section_enable',
	) ) );
	// recent btn link setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[recent_ads_link]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[recent_ads_link]', array(
		'label'           	=> esc_html__( 'Ads Link', 'musicsong-pro' ),
		'section'        	=> 'musicsong_pro_recent_section',
		'active_callback' 	=> 'musicsong_pro_is_recent_section_enable',
		'type'				=> 'url',
	) );