<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'musicsong_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','musicsong-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_slider_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );


if ( $options['home_layout'] == 'third-design' ) {
	$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_btn_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_btn_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'musicsong_pro_theme_options[slider_btn_title]', array(
		'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
		'section'        	=> 'musicsong_pro_slider_section',
		'active_callback' 	=> 'musicsong_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );
}


if ( $options['home_layout'] !== 'third-design' ) {
	// Slider search enable control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_search_enable]', array(
		'default'			=> 	$options['slider_search_enable'],
		'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[slider_search_enable]', array(
		'label'             => esc_html__( 'Slider Search Enable', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_slider_section',
		'on_off_label' 		=> musicsong_pro_switch_options(),
		'active_callback' 	=> 'musicsong_pro_is_slider_section_enable',
	) ) );
}



// Slider content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_slider_section_enable',
	'choices'			=> musicsong_pro_slider_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
	'validate_callback' => 'musicsong_pro_validate_slider_count',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_slider_section',
	'active_callback'   => 'musicsong_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_slider_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_slider_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_slider_section_content_post_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[slider_content_product_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[slider_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_slider_section',
		'choices'			=> musicsong_pro_product_choices(),
		'active_callback'	=> 'musicsong_pro_is_slider_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_slider_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[slider_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[slider_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_slider_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_slider_section_content_product_category_enable'
) ) );