<?php
/**
 * tour Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add tour section
$wp_customize->add_section( 'musicsong_pro_tour_section', array(
	'title'             => esc_html__( 'Polular Tour','musicsong-pro' ),
	'description'       => esc_html__( 'Popular Tour Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// tour content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_section_enable]', array(
	'default'			=> 	$options['tour_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[tour_section_enable]', array(
	'label'             => esc_html__( 'tour Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_tour_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// tour title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['tour_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[tour_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_tour_section',
	'active_callback' 	=> 'musicsong_pro_is_tour_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[tour_title]', array(
		'selector'            => '#travel-tours .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[tour_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_tour_title_partial',
    ) );
}

// tour description setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['tour_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[tour_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_tour_section',
	'active_callback' 	=> 'musicsong_pro_is_tour_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[tour_subtitle]', array(
		'selector'            => '#travel-tours .section-header span.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[tour_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_tour_subtitle_partial',
    ) );
}


$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_subtitle_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[tour_subtitle_url]', array(
	'label'           	=> esc_html__( 'Sub Title Url', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_tour_section',
	'type'				=> 'url',
	'active_callback' 	=> 'musicsong_pro_is_tour_section_enable',
) );

// tour number control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_count]', array(
	'default'          	=> $options['tour_count'],
	'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[tour_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_tour_section',
	'active_callback'   => 'musicsong_pro_is_tour_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// tour content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_content_type]', array(
	'default'          	=> $options['tour_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'category' 	=> esc_html__( 'Category', 'musicsong-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'musicsong-pro' );
	$choices['tour'] = esc_html__( 'tour', 'musicsong-pro' );
}

$wp_customize->add_control( 'musicsong_pro_theme_options[tour_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_tour_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_tour_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= $options['tour_count']; $i++ ) :
	// tour pages drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[tour_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_tour_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_tour_section_content_page_enable',
	) ) );

	// tour posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[tour_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_tour_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_tour_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[tour_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'musicsong-pro' ), $i ),
			'section'           => 'musicsong_pro_tour_section',
			'choices'			=> musicsong_pro_trip_choices(),
			'active_callback'	=> 'musicsong_pro_is_tour_section_content_trip_enable',
		) ) );
	}

	// tour hr setting and control
	$wp_customize->add_setting( 'musicsong_pro_theme_options[tour_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Musicsong_Pro_Customize_Horizontal_Line( $wp_customize, 'musicsong_pro_theme_options[tour_hr_'. $i .']',
		array(
			'section'         => 'musicsong_pro_tour_section',
			'active_callback' => 'musicsong_pro_is_tour_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[tour_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[tour_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: tour selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_tour_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_tour_section_content_category_enable'
) ) );

if ( class_exists( 'WP_Travel' ) ) {
	// Add dropdown tours setting and control.
	$wp_customize->add_setting(  'musicsong_pro_theme_options[dest_tours]', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[dest_tours]', array(
		'label'             => esc_html__( 'Select tours', 'musicsong-pro' ),
		'description'      	=> esc_html__( 'Note: Selected tour\'s no of posts will be shown from selected category', 'musicsong-pro' ),
		'section'           => 'musicsong_pro_tour_section',
		'type'              => 'dropdown-taxonomies',
		'taxonomy'			=> 'travel_locations',
		'active_callback'	=> 'musicsong_pro_is_dest_tours_enable'
	) ) );
}