<?php
/**
 * featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
$options = musicsong_pro_get_theme_options();
if ( $options['home_layout'] == 'sixth-design'  ) {
    if ( ! function_exists( 'musicsong_pro_add_featured_section' ) ) :
        /**
        * Add featured section
        *
        *@since Musicsong Pro 1.0.0
        */
        function musicsong_pro_add_featured_section() {
            $options = musicsong_pro_get_theme_options();
            // Check if featured is enabled on frontpage
            $featured_enable = apply_filters( 'musicsong_pro_section_status', true, 'featured_section_enable' );

            if ( true !== $featured_enable ) {
                return false;
            }
            // Get featured section details
            $section_details = array();
            $section_details = apply_filters( 'musicsong_pro_filter_featured_section_details', $section_details );

            if ( empty( $section_details ) ) {
                return;
            }

            // Render featured section now.
            musicsong_pro_render_featured_section( $section_details );
        }
    endif;

    if ( ! function_exists( 'musicsong_pro_get_featured_section_details' ) ) :
        /**
        * featured section details.
        *
        * @since Musicsong Pro 1.0.0
        * @param array $input featured section details.
        */
        function musicsong_pro_get_featured_section_details( $input ) {
            $options = musicsong_pro_get_theme_options();

            // Content type.
            $featured_content_type  = $options['featured_content_type'];
            $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 4;
            
            $content = array();
            switch ( $featured_content_type ) {
                
                case 'page':
                    $page_ids = array();

                    for ( $i = 1; $i <= $featured_count; $i++ ) {
                        if ( ! empty( $options['featured_content_page_' . $i] ) )
                            $page_ids[] = $options['featured_content_page_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'page',
                        'post__in'          => ( array ) $page_ids,
                        'posts_per_page'    => absint( $featured_count ),
                        'orderby'           => 'post__in',
                        );                    
                break;

                case 'post':
                    $post_ids = array();

                    for ( $i = 1; $i <= $featured_count; $i++ ) {
                        if ( ! empty( $options['featured_content_post_' . $i] ) )
                            $post_ids[] = $options['featured_content_post_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'post',
                        'post__in'          => ( array ) $post_ids,
                        'posts_per_page'    => absint( $featured_count ),
                        'orderby'           => 'post__in',
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'category':
                    $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                    $args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => absint( $featured_count ),
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'recent':
                    $cat_ids = ! empty( $options['featured_category_exclude'] ) ? $options['featured_category_exclude'] : array();
                    $args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => absint( $featured_count ),
                        'category__not_in'  => ( array ) $cat_ids,
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                default:
                break;
            }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

                
            if ( ! empty( $content ) ) {
                $input = $content;
            }
            return $input;
        }
    endif;
    // featured section content details.
    add_filter( 'musicsong_pro_filter_featured_section_details', 'musicsong_pro_get_featured_section_details' );


    if ( ! function_exists( 'musicsong_pro_render_featured_section' ) ) :
      /**
       * Start featured section
       *
       * @return string featured content
       * @since Musicsong Pro 1.0.0
       *
       */
       function musicsong_pro_render_featured_section( $content_details = array() ) {
            $options = musicsong_pro_get_theme_options();
            $featured_content_type  = $options['featured_content_type'];
            $column = ! empty( $options['featured_column'] ) ? $options['featured_column'] : 'col-3';
            $i = 1;

            if ( empty( $content_details ) ) {
                return;
            } ?>

            <div id="magazine-featured-posts">
                <div class="wrapper">
                    <?php if ( $options['featured_title'] !== '' ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ) ?></h2>
                        </div><!-- .section-header -->
                    <?php endif ?>
                    

                    <div class="col-4 clear">
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="featured-post-item">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['image'] ) ?>">

                                        <span class="posted-on">
                                           <?php musicsong_pro_posted_on( $content['id'] ) ?>
                                        </span><!-- .posted-on -->
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <?php the_category( '', '', $content['id'] ) ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>  

                                        <div class="entry-content">
                                            <?php echo esc_html( $content['excerpt'] ) ?>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-post-item -->
                            </article>
                        <?php endforeach ?>                        
                    </div><!-- .col-4 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-featured-posts -->

        <?php }
    endif;
}else{
    if ( ! function_exists( 'musicsong_pro_add_featured_section' ) ) :
        /**
        * Add featured section
        *
        *@since Musicsong Pro 1.0.0
        */
        function musicsong_pro_add_featured_section() {
            $options = musicsong_pro_get_theme_options();
            // Check if featured is enabled on frontpage
            $featured_enable = apply_filters( 'musicsong_pro_section_status', true, 'featured_section_enable' );

            if ( ( true !== $featured_enable) || ! class_exists( 'WooCommerce' ) ) {
                return false;
            }

            // Render featured section now.
            musicsong_pro_render_featured_section();
        }
    endif;

    if ( ! function_exists( 'musicsong_pro_render_featured_section' ) ) :
      /**
       * Start featured section
       *
       * @return string featured content
       * @since Musicsong Pro 1.0.0
       *
       */
       function musicsong_pro_render_featured_section() {
            $options = musicsong_pro_get_theme_options();

        ?>
        <div id="featured-products" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-content clear col-2">
                            
                <?php for ( $i=1; $i <= 2 ; $i++ ) { 
                    if ( empty($options['featured_content_featured_category_'.$i]) ) {
                        return;
                    }
                    $thumbnail_id = get_term_meta( $options['featured_content_featured_category_'.$i], 'thumbnail_id', true );
                    $image = wp_get_attachment_url( $thumbnail_id );
                    $cat_name = get_term_by( 'id', $options['featured_content_featured_category_'.$i], 'product_cat' )->name;
                    $banner_title = empty( $options['featured_banner_title_'.$i] ) ? '' : $options['featured_banner_title_'.$i];
                    $banner_sub_title = empty( $options['featured_banner_sub_title_'.$i] ) ? '' : $options['featured_banner_sub_title_'.$i];
                    $cat_link = get_category_link( $options['featured_content_featured_category_'.$i] );
                ?>
                     <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            <div class="entry-container">
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <li><a href="<?php echo esc_url( $cat_link ) ?>"><?php echo esc_html( $cat_name ); ?></a></li>
                                    </ul>
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $cat_link ) ?>"><?php echo esc_html( $banner_title ) ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $banner_sub_title ) ?></p>
                                </div>

                                <div class="read-more">
                                    <a href="<?php echo esc_url( $cat_link ) ?>" class="btn"><?php echo esc_html__( 'Start Shopping', 'musicsong-pro' ) ?></a>
                                </div><!-- .read-more -->
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>
                <?php } ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

        <?php }
    endif;

}
