<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_gallery_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'musicsong_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        musicsong_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input gallery section details.
    */
    function musicsong_pro_get_gallery_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_count = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 5;

        $content = array();
        switch ( $gallery_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['gallery_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_product_' . $i] ) )
                        $page_ids[] = $options['gallery_content_product_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['gallery_content_product_category'] ) ? $options['gallery_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $gallery_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = musicsong_pro_trim_content( 45 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'musicsong_pro_filter_gallery_section_details', 'musicsong_pro_get_gallery_section_details' );


if ( ! function_exists( 'musicsong_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_gallery_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $gallery_content_type  = $options['gallery_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-gallery" class="relative page-section modern-slider">
            <div class="wrapper">
                <?php if ( ! empty( $options['gallery_title'] ) || ! empty( $options['gallery_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['gallery_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $options['gallery_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['gallery_subtitle'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="gallery-slider" data-slick='{"slidesToShow": 5, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": true, "draggable": true, "fade": false, "centerMode": true, "focusOnSelect": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="gallery-item-wrapper" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .gallery-item-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .gallery-slider -->
            </div><!-- .wrapper -->
        </div><!-- #gallery-slider -->

    <?php }
endif;