<?php 
if ( ! function_exists( 'musicsong_pro_add_recent_section' ) ) :
        /**
        * Add recent section
        *
        *@since Musicsong Pro 1.0.0
        */
        function musicsong_pro_add_recent_section() {
            $options = musicsong_pro_get_theme_options();
            // Check if recent is enabled on frontpage
            $recent_enable = apply_filters( 'musicsong_pro_section_status', true, 'recent_section_enable' );

            if ( true !== $recent_enable ) {
                return false;
            }
            // Get recent section details
            $section_details = array();
            $section_details = apply_filters( 'musicsong_pro_filter_recent_section_details', $section_details );

            if ( empty( $section_details ) ) {
                return;
            }

            // Render recent section now.
            musicsong_pro_render_recent_section( $section_details );
        }
    endif;

    if ( ! function_exists( 'musicsong_pro_get_recent_section_details' ) ) :
        /**
        * recent section details.
        *
        * @since Musicsong Pro 1.0.0
        * @param array $input recent section details.
        */
        function musicsong_pro_get_recent_section_details( $input ) {
            $options = musicsong_pro_get_theme_options();

            // Content type.
            $recent_content_type  = $options['recent_content_type'];
            $recent_count = ! empty( $options['recent_count'] ) ? $options['recent_count'] : 4;
            
            $content = array();
            switch ( $recent_content_type ) {
                
                case 'page':
                    $page_ids = array();

                    for ( $i = 1; $i <= $recent_count; $i++ ) {
                        if ( ! empty( $options['recent_content_page_' . $i] ) )
                            $page_ids[] = $options['recent_content_page_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'page',
                        'post__in'          => ( array ) $page_ids,
                        'posts_per_page'    => absint( $recent_count ),
                        'orderby'           => 'post__in',
                        );                    
                break;

                case 'post':
                    $post_ids = array();

                    for ( $i = 1; $i <= $recent_count; $i++ ) {
                        if ( ! empty( $options['recent_content_post_' . $i] ) )
                            $post_ids[] = $options['recent_content_post_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'post',
                        'post__in'          => ( array ) $post_ids,
                        'posts_per_page'    => absint( $recent_count ),
                        'orderby'           => 'post__in',
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'category':
                    $cat_id = ! empty( $options['recent_content_category'] ) ? $options['recent_content_category'] : '';
                    $args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => absint( $recent_count ),
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'recent':
                    $cat_ids = ! empty( $options['recent_category_exclude'] ) ? $options['recent_category_exclude'] : array();
                    $args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => absint( $recent_count ),
                        'category__not_in'  => ( array ) $cat_ids,
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                default:
                break;
            }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

                
            if ( ! empty( $content ) ) {
                $input = $content;
            }
            return $input;
        }
    endif;
    // recent section content details.
    add_filter( 'musicsong_pro_filter_recent_section_details', 'musicsong_pro_get_recent_section_details' );


    if ( ! function_exists( 'musicsong_pro_render_recent_section' ) ) :
      /**
       * Start recent section
       *
       * @return string recent content
       * @since Musicsong Pro 1.0.0
       *
       */
       function musicsong_pro_render_recent_section( $content_details = array() ) {
            $options = musicsong_pro_get_theme_options();
            $recent_content_type  = $options['recent_content_type'];
            $column = ! empty( $options['recent_column'] ) ? $options['recent_column'] : 'col-3';
            $i = 1;

            if ( empty( $content_details ) ) {
                return;
            } ?>

            <div id="magazine-recent-posts">
                <div class="wrapper">
                    <?php if ( $options['recent_title'] !== '' ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['recent_title'] ) ?></h2>
                        </div><!-- .section-header -->
                    <?php endif ?>
                    

                    <div class="col-3 clear">
                        <?php foreach ($content_details as $content): ?>
                            <article>
                                <div class="featured-post-item">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['image'] ) ?>">
                                        <?php musicsong_pro_posted_on( $content['id'] ) ?>
                                    </div><!-- .recent-image -->

                                    <div class="entry-container">
                                        <?php the_category( '', '', $content['id'] ) ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>  

                                        <div class="entry-content">
                                            <?php echo esc_html( $content['excerpt'] ) ?>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .recent-post-item -->
                            </article>
                        <?php endforeach ?>                        
                    </div><!-- .col-4 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-recent-posts -->
            <?php if ( !empty( $options['recent_ads_image'] ) ): ?>
                <div id="magazine-advertisement-section">
                    <div class="wrapper">
                        <a href="<?php echo esc_url( $options['recent_ads_url'] ) ?>"><img src="<?php echo esc_url( $options['recent_ads_image'] ) ?>"></a>
                    </div><!-- .wrapper -->
                </div><!-- #magazine-advertisement-section -->
            <?php endif ?>
            
        <?php }
    endif;