<?php
/**
 * tour section
 *
 * This is the template for the content of tour section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_tour_section' ) ) :
    /**
    * Add tour section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_tour_section() {
        $options = musicsong_pro_get_theme_options();
        // Check if tour is enabled on frontpage
        $tour_enable = apply_filters( 'musicsong_pro_section_status', true, 'tour_section_enable' );

        if ( true !== $tour_enable ) {
            return false;
        }
        // Get tour section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_tour_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render tour section now.
        musicsong_pro_render_tour_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_tour_section_details' ) ) :
    /**
    * tour section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input tour section details.
    */
    function musicsong_pro_get_tour_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $tour_content_type  = $options['tour_content_type'];
        $tour_count = ! empty( $options['tour_count'] ) ? $options['tour_count'] : 2;
        
        $content = array();
        switch ( $tour_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_content_page_' . $i] ) )
                        $page_ids[] = $options['tour_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $tour_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_content_post_' . $i] ) )
                        $post_ids[] = $options['tour_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $tour_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $trip_ids = array();

                for ( $i = 1; $i <= $tour_count; $i++ ) {
                    if ( ! empty( $options['tour_content_trip_' . $i] ) )
                        $trip_ids[] = $options['tour_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $trip_ids,
                    'posts_per_page'    => absint( $tour_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tour':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $dest_id = ! empty( $options['dest_tours'] ) ? $options['dest_tours'] : '';
                $args = array(
                    'post_type'         => 'itineraries',
                    'posts_per_page'    => absint( $tour_count ),
                    // 'cat'               => absint( $dest_id ),
                    'ignore_sticky_posts'   => true,
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field' => 'term_id',
                            'terms'  => $dest_id,
                        )
                    ),
                );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['tour_content_category'] ) ? $options['tour_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $tour_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_ID();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['img']       = get_the_post_thumbnail_url( get_the_ID(), 'large' );
                $page_post['excerpt']   = musicsong_pro_trim_content( 15 );

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// tour section content details.
add_filter( 'musicsong_pro_filter_tour_section_details', 'musicsong_pro_get_tour_section_details' );


if ( ! function_exists( 'musicsong_pro_render_tour_section' ) ) :
  /**
   * Start tour section
   *
   * @return string tour content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_tour_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $content_type = $options['tour_content_type'];
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="popular-tours" class="page-section relative">
            <div class="wrapper">
                <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['tour_title'] ); ?></h2>
                <div class="view-all">
                    <a href="<?php echo esc_html( $options['tour_subtitle_url'] ); ?>" class="view-all" target="_blank"><?php echo esc_html( $options['tour_subtitle'] ); ?><i class="fa fa-long-arrow-right"></i></a>
                </div><!-- .view-all -->
            </div><!-- .section-header -->

                <div class="section-content col-3 clear">
                    <?php foreach ($content_details as $content): ?>
                    <article>
                        <div class="popular-tours-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                    </h2>
                                </header>

                                <?php if ( ( 'trip' == $content_type || 'tour' == $content_type ) && class_exists( 'WP_Travel' ) ) { 
                                    $trip_price = wp_travel_get_price( $content['id'] );
                                    ?>
                                     <div class="popular-tours-meta">
                                        <span class="popular-tours-trip-duration">
                                            <?php wp_travel_get_trip_duration( $content['id'] ); ?>                                 
                                        </span><!-- .popular-tours-trip-duration -->

                                        <span class="popular-tours-trip-price"><?php  echo wp_kses_post( wp_travel_get_formated_price_currency( $trip_price ) ); ?></span><!-- .popular-tours-trip-price -->
                                    </div><!-- .popular-tours-meta -->
                                <?php } ?>
                               
                            </div><!-- .entry-container -->
                        </div><!-- .popular-tours-wrapper -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>        
    <?php }
endif;