<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

$options = musicsong_pro_get_theme_options();


if ( ! function_exists( 'musicsong_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Musicsong Pro 1.0.0
	 */
	function musicsong_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'musicsong_pro_doctype', 'musicsong_pro_doctype', 10 );


if ( ! function_exists( 'musicsong_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'musicsong_pro_before_wp_head', 'musicsong_pro_head', 10 );

if ( ! function_exists( 'musicsong_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'musicsong-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'musicsong_pro_page_start_action', 'musicsong_pro_page_start', 10 );

if ( ! function_exists( 'musicsong_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'musicsong_pro_page_end_action', 'musicsong_pro_page_end', 10 );

if ( ! function_exists( 'musicsong_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_header_start() { ?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'musicsong_pro_header_action', 'musicsong_pro_header_start', 10 );

if ( ! function_exists( 'musicsong_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_site_branding() {
		$options  = musicsong_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<?php if ( $options['home_layout'] == 'sixth-design' ): ?>
			<div class="site-branding-wrapper">
				<div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php } 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
						<div id="site-details">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( musicsong_pro_is_latest_posts() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->
				<?php if ( !empty($options['menu_ads_link']) ): ?>
					<div class="site-advertisement">
	                    <a href="<?php echo esc_url( $options['menu_ads_link'] ) ?>"><img src="<?php echo esc_url( $options['menu_ads_image'] ) ?>"></a>
	                </div>
				<?php endif ?>
				
			</div>
		<?php endif ?>
		<?php if ( $options['home_layout'] !== 'sixth-design' ): ?>
			<div class="site-menu">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
	                <?php
					echo musicsong_pro_get_svg( array( 'icon' => 'menu' ) );
					echo musicsong_pro_get_svg( array( 'icon' => 'close' ) );
					?>	
	                <span class="menu-label"><?php esc_html_e( 'Menu', 'musicsong-pro' ); ?></span>
	            </button><!-- .menu-toggle -->

				<div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php } 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
						<div id="site-details">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( musicsong_pro_is_latest_posts() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->
		<?php endif ?>
		
		<?php
	}
endif;
add_action( 'musicsong_pro_header_action', 'musicsong_pro_site_branding', 20 );

if ( ! function_exists( 'musicsong_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_site_navigation() { 
		$options  = musicsong_pro_get_theme_options();
		?>

		<?php if ( $options['home_layout'] !== 'sixth-design' ): ?>
			<nav id="site-navigation" class="main-navigation" role="navigation">
				<?php  
					$cart = '';
					if ( class_exists( 'WooCommerce' ) ) :
						$cart = '<li><a class="cart-icon" href="'. esc_url( wc_get_cart_url() ) .'">';
						$cart .= musicsong_pro_get_svg( array( 'icon' => 'cart' ) );
						$cart .= '<small>'. wp_kses_data( WC()->cart->get_cart_contents_count() ) .'</small>';
						$cart .= '</a></li>';
	                endif;

					$social_menu = wp_nav_menu(array(
	        			'theme_location' => 'social',
	        			'container' => 'div',
	    				'container_class' => 'social-icons',
	        			'menu_class' => '',
	        			'menu_id' => '',
	        			'echo' => false,
	        			'depth' => 1,
	        			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
						'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $cart . '</ul>',
	        		));

	        	
	        		wp_nav_menu( array(
	        			'theme_location' => 'primary',
	        			'container' => false,
	        			'menu_class' => 'menu nav-menu',
	        			'menu_id' => 'primary-menu',
	        			'echo' => true,
	        			'fallback_cb' => 'musicsong_pro_menu_fallback_cb',
	        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s<li class="social-menu-item">' . $social_menu . '</li></ul>',
	        		) );
	        	?>
			</nav><!-- #site-navigation -->
			</div><!-- .site-menu -->
		<?php endif ?>

		<?php if ( $options['home_layout'] == 'sixth-design' ): ?>
			<div id="site-menu">
                <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                    <svg viewBox="0 0 40 40" class="icon-menu">
                        <rect y="7" width="40" height="2"></rect>
                        <rect y="19" width="40" height="2"></rect>
                        <rect y="31" width="40" height="2"></rect>
                    </svg>

                    <svg viewBox="0 0 612 612" class="icon-close">
                        <polygon points="612,36.004 576.521,0.603 306,270.608 35.478,0.603 0,36.004 270.522,306.011 0,575.997 35.478,611.397 
                        306,341.411 576.521,611.397 612,575.997 341.459,306.011"></polygon>
                    </svg>
                    <span class="menu-label">Menu</span>
                </button><!-- .menu-toggle -->

                <nav id="site-navigation" class="main-navigation" role="navigation">
				<?php  
					$cart = '';
					if ( class_exists( 'WooCommerce' ) ) :
						$cart = '<li><a class="cart-icon" href="'. esc_url( wc_get_cart_url() ) .'">';
						$cart .= musicsong_pro_get_svg( array( 'icon' => 'cart' ) );
						$cart .= '<small>'. wp_kses_data( WC()->cart->get_cart_contents_count() ) .'</small>';
						$cart .= '</a></li>';
	                endif;

					$social_menu = wp_nav_menu(array(
	        			'theme_location' => 'social',
	        			'container' => 'div',
	    				'container_class' => 'social-icons',
	        			'menu_class' => '',
	        			'menu_id' => '',
	        			'echo' => false,
	        			'depth' => 1,
	        			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
						'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $cart . '</ul>',
	        		));

	        	
	        		wp_nav_menu( array(
	        			'theme_location' => 'primary',
	        			'container' => false,
	        			'menu_class' => 'menu nav-menu',
	        			'menu_id' => 'primary-menu',
	        			'echo' => true,
	        			'fallback_cb' => 'musicsong_pro_menu_fallback_cb',
	        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s<li class="social-menu-item">' . $social_menu . '</li></ul>',
	        		) );
	        	?>
			</nav><!-- #site-navigation -->

            </div><!-- #site-menu -->
		<?php endif ?>

		

		<?php
	}
endif;
add_action( 'musicsong_pro_header_action', 'musicsong_pro_site_navigation', 30 );
if ( $options['home_layout'] !== 'sixth-design' ): 


	if ( ! function_exists( 'musicsong_pro_social_navigation' ) ) :
		/**
		 * Social navigation codes
		 *
		 * @since Musicsong Pro 1.0.0
		 *
		 */
		function musicsong_pro_social_navigation() {
			?>
			 <div id="social-navigation">
				<?php  
					$cart = '';
					if ( class_exists( 'WooCommerce' ) ) :
						$cart = '<li><a class="cart-icon" href="'. esc_url( wc_get_cart_url() ) .'">';
						$cart .= musicsong_pro_get_svg( array( 'icon' => 'cart' ) );
						$cart .= '<small>'. wp_kses_data( WC()->cart->get_cart_contents_count() ) .'</small>';
						$cart .= '</a></li>';
	                endif;

	        		$defaults = array(
	        			'theme_location' => 'social',
	        			'container' => 'div',
	    				'container_class' => 'social-icons',
	        			'menu_class' => '',
	        			'menu_id' => '',
	        			'echo' => true,
	        			'fallback_cb' => 'musicsong_pro_menu_fallback_cb',
	        			'depth' => 1,
	        			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
						'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $cart . '</ul>',
	        		);
	        		
	        		wp_nav_menu( $defaults );
	        	?>
			</div><!-- #social-navigation -->
			<?php
		}
	endif;
	add_action( 'musicsong_pro_header_action', 'musicsong_pro_social_navigation', 40 );
endif;

if ( ! function_exists( 'musicsong_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'musicsong_pro_header_action', 'musicsong_pro_header_end', 50 );

if ( ! function_exists( 'musicsong_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'musicsong_pro_content_start_action', 'musicsong_pro_content_start', 10 );

if ( ! function_exists( 'musicsong_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_header_image() {
		if ( musicsong_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php musicsong_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php musicsong_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'musicsong_pro_header_image_action', 'musicsong_pro_header_image', 10 );

if ( ! function_exists( 'musicsong_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Musicsong Pro 1.0.0
	 */
	function musicsong_pro_add_breadcrumb() {
		$options = musicsong_pro_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( musicsong_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * musicsong_pro_simple_breadcrumb hook
				 *
				 * @hooked musicsong_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'musicsong_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'musicsong_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'musicsong_pro_content_end_action', 'musicsong_pro_content_end', 10 );

if ( ! function_exists( 'musicsong_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'musicsong_pro_footer', 'musicsong_pro_footer_start', 10 );

if ( ! function_exists( 'musicsong_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_footer_site_info() {
		$options = musicsong_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info col-3">
            <div class="wrapper">
                <span>
                	<?php 
                	echo musicsong_pro_santize_allow_tag( $copyright_text ); 
                	if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( ' | ' );
					}
                	?>
            	</span>

            	<?php  
            		$defaults = array(
	        			'theme_location' => 'footer',
	        			'container' => 'div',
	        			'container_class' => 'custom-menu',
	        			'menu_class' => false,
	        			'menu_id' => false,
	        			'echo' => true,
	        			'fallback_cb' => 'musicsong_pro_menu_fallback_cb',
	        		);
	        	
	        		wp_nav_menu( $defaults );

	        		$defaults = array(
	        			'theme_location' => 'social',
	        			'container' => 'div',
	    				'container_class' => 'social-icons',
	        			'menu_class' => '',
	        			'menu_id' => '',
	        			'echo' => true,
	        			'fallback_cb' => 'musicsong_pro_menu_fallback_cb',
	        			'depth' => 1,
	        			'link_before' => '<span class="screen-reader-text">',
						'link_after' => '</span>',
	        		);
	        		
	        		wp_nav_menu( $defaults );
            	?>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'musicsong_pro_footer', 'musicsong_pro_footer_site_info', 40 );

if ( ! function_exists( 'musicsong_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_footer_scroll_to_top() {
		$options  = musicsong_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo musicsong_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'musicsong_pro_footer', 'musicsong_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'musicsong_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'musicsong_pro_footer', 'musicsong_pro_footer_end', 100 );

if ( ! function_exists( 'musicsong_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_loader() {
		$options = musicsong_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo musicsong_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'musicsong_pro_before_header', 'musicsong_pro_loader', 10 );

if ( ! function_exists( 'musicsong_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Musicsong Pro 1.0.0
	 *
	 */
	function musicsong_pro_infinite_loader_spinner() { 
		global $post;
		$options = musicsong_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . musicsong_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'musicsong_pro_infinite_loader_spinner_action', 'musicsong_pro_infinite_loader_spinner', 10 );
